.. _pnps-gen:

pnps-gen - pN/pS Table Generation
=================================

Overview
--------

.. automodule:: mgkit.workflow.pnps_gen


Options
-------

.. click:: mgkit.workflow.pnps_gen:main
   :prog: pnps-gen
   :show-nested:
